clear
drop _all
set more on

use "C:\Users\marcb\Desktop\Price Risk Experiments Stata\risk_Jan2017.dta"

replace price=7 if setting==1 & price~=7

* Generating Relative Risk Aversion Based Off of CRRA *

gen R = -0.95 if round>10 & (switch==1)
replace R = -0.49 if switch==2 & round>10
replace R = -0.15 if switch==3 & round>10
replace R = 0.15 if switch==4 & round>10
replace R = 0.41 if switch==5 & round>10
replace R = 0.68 if switch==6 & round>10
replace R = 0.97 if switch==7 & round>10
replace R = 1.37 if switch==8 & round>10
replace R = 1.50 if round>10 & (switch==9 | switch==10)

gen us = 1 if peru==0

gen minnesota = (october==1)

gen cornell = (december==1 | march==1)

gen session_a = 1 if december==1
replace session_a = 2 if march==1
replace session_a = 3 if october==1
replace session_a = 4 if peru==1

gen sid = session_a*1000 + id

gen session = 1 if december==1
replace session = 2 if march==1
replace session = 3 if october==1
replace session = sid if peru==1

drop if pilot==1

gen hl_first = (dice_6 > 3)
replace hl_first = 0 if december==1
replace hl_first = 1 if march==1 | october==1

count

duplicates report sid

sort sid round
drop profit_lag price_lag 
by sid: gen profit_lag = profit[_n-1]
by sid: gen price_lag = price[_n-1]
by sid: gen gain_lag = profit_lag if profit_lag>0
by sid: replace gain_lag = 0 if profit_lag<=0

by sid: gen loss_lag = abs(profit_lag) if profit_lag<0
by sid: replace loss_lag = 0 if profit_lag>=0

by sid: gen prod_lag = prod[_n-1]

gen unc_gain = uncertainty*gain_lag
gen unc_loss = uncertainty*loss_lag

gen std_gain = stdev*gain_lag
gen std_loss = stdev*loss_lag

xtset sid round

xtreg prod uncertainty stdev R hl_first round if round>10, re i(sid)
est store re

xtreg prod uncertainty stdev R hl_first round if round>10, fe i(sid)
est store fe

hausman fe re


* xtnbreg wouldn't converge in either case *

xtpoisson prod uncertainty stdev R hl_first round if round>10, re i(sid)
est store cre

xtpoisson prod uncertainty stdev R hl_first round if round>10, fe i(sid)
est store cfe

hausman cre cfe



gen gender = (male==2) if male~=.
replace gender = female if gender==.
drop female male
rename gender female


gen screening = (screening_1==40 & screening_2==75 & screening_3==30)

gen cornell_unc = cornell*uncertainty
gen minnesota_unc = minnesota*uncertainty
gen peru_unc = peru*uncertainty

gen cornell_stdev = cornell*stdev
gen minnesota_stdev = minnesota*stdev
gen peru_stdev = peru*stdev

* Price Risk, As Distinct from Income Risk *

* Profit Risk (Show Both) *

gen pr_5 = 0 if setting==1
gen pr_6 = 0 if setting==1
gen pr_7 = 1 if setting==1
gen pr_8 = 0 if setting==1
gen pr_9 = 0 if setting==1

replace pr_5 = 0 if setting==2
replace pr_6 = 6/20 if setting==2
replace pr_7 = 8/20 if setting==2
replace pr_8 = 6/20 if setting==2
replace pr_9 = 0 if setting==2

replace pr_5 = 2/20 if setting==3
replace pr_6 = 5/20 if setting==3
replace pr_7 = 6/20 if setting==3
replace pr_8 = 5/20 if setting==3
replace pr_9 = 2/20 if setting==3

replace pr_5 = 4/20 if setting==4
replace pr_6 = 4/20 if setting==4
replace pr_7 = 4/20 if setting==4
replace pr_8 = 4/20 if setting==4
replace pr_9 = 4/20 if setting==4

replace pr_5 = 6/20 if setting==5
replace pr_6 = 0 if setting==5
replace pr_7 = 7/20 if setting==5
replace pr_8 = 0 if setting==5
replace pr_9 = 6/20 if setting==5

foreach i in 0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 {
gen risk_`i' = ((pr_5*`i'*5 + pr_6*`i'*6 + pr_7*`i'*7 + pr_8*`i'*8 + pr_9*`i'*9)^2 - (pr_7*`i'*7)^2) - (2*`i'^(1.4) + 15)
}

gen risk = (risk_0+risk_1+risk_2+risk_3+risk_4+risk_5+risk_6+risk_7+risk_8+risk_9+risk_10+risk_11+risk_12+risk_13+risk_14+risk_15+risk_16+risk_17+risk_18+risk_19+risk_20)/21



gen risk_output=.
foreach i in 0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 {
replace risk_output = risk_`i' if prod==`i'
}

xtreg prod uncertainty stdev risk R hl_first female round if round>10 & switch~=0, re i(sid) cluster(sid)
more

xtreg prod uncertainty stdev risk_output R hl_first female round if round>10 & switch~=0, re i(sid) cluster(sid)
more

label variable prod "Output"
label variable uncertainty "Uncertainty"
label variable stdev "Standard Deviation"
label variable R "Arrow-Pratt Coefficient of RRA"
label variable hl_first "Holt-Laury First"
label variable female "Female"
label variable round "Round"

drop pr_*

* Histograms *

* Overall *

histogram prod if round>10 & switch~=0, w(1) b(20) s(0) normal title(Output Choices - All Rounds with Pooled Data)
more


* By Uncertainty *

histogram prod if uncertainty==0 & round>10 & switch~=0, w(1) b(20) s(0) normal title(Output Choices - Price Certainty Rounds with Pooled Data)
more
histogram prod if uncertainty==1 & round>10 & switch~=0, w(1) b(20) s(0) normal title(Output Choices - Price Risk with Pooled Data)
more

* By Context *

histogram prod if cornell==1 & december==1 & round>10 & switch~=0 & uncertainty==0, w(1) b(20) s(0) title(Certainty Rounds Output Choices Cornell December 2014)
more
histogram prod if cornell==1 & march==1 & round>10 & switch~=0 & uncertainty==0, w(1) b(20) s(0) title(Certainty Rounds Output Choices Cornell March 2015)
more
histogram prod if minnesota==1 & round>10 & switch~=0& uncertainty==0, w(1) b(20) s(0) title(Certainty Rounds Output Choices Minnesota)
more
histogram prod if peru==1 & round>10 & switch~=0& uncertainty==0, w(1) b(20) s(0) title(Certainty Rounds Output Choices Peru)
more


histogram prod if cornell==1 & december==1 & round>10 & switch~=0& uncertainty==1, w(1) b(20) s(0) title(Uncertainty Rounds Output Choices December 2014)
more
histogram prod if cornell==1 & march==1 & round>10 & switch~=0& uncertainty==1, w(1) b(20) s(0) title(Uncertainty Rounds Output Choices Cornell March 2015)
more
histogram prod if minnesota==1 & round>10 & switch~=0& uncertainty==1, w(1) b(20) s(0) title(Uncertainty Rounds Output Choices Minnesota)
more
histogram prod if peru==1 & round>10 & switch~=0& uncertainty==1, w(1) b(20) s(0) title(Uncertainty Rounds Output Choices Peru)
more

twoway (histogram prod if cornell==1 & december==1 & round>10 & switch~=0& uncertainty==1, width(1) color(green)) ///
       (histogram prod if cornell==1 & march==1 & round>10 & switch~=0& uncertainty==1, width(1) ///
	   fcolor(none) lcolor(black)), legend(order(1 "Cornell 1" 2 "Cornell 2" ))

twoway (histogram prod if minnesota==1 & uncertainty==1 & round>10 & switch~=0, width(1) color(green)) ///
       (histogram prod if peru==1 & uncertainty==1 & round>10 & switch~=0, width(1) ///
	   fcolor(none) lcolor(black)), legend(order(1 "Minnesota" 2 "Peru" ))

* Descriptive Stats *

outreg2 using c:\data\sandmo_t1, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xi: mean prod price uncertainty stdev i.setting R hl_first if round>10 & switch~=0
outreg2 using c:\data\sandmo_t1, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xi: mean prod price uncertainty stdev i.setting R hl_first if round>10 & switch~=0 & cornell==1 & december==1
outreg2 using c:\data\sandmo_t1, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xi: mean prod price uncertainty stdev i.setting R hl_first if round>10 & switch~=0 & cornell==1 & march==1
outreg2 using c:\data\sandmo_t1, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xi: mean prod price uncertainty stdev i.setting R hl_first if round>10 & switch~=0 & minnesota==1
outreg2 using c:\data\sandmo_t1, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xi: mean prod price uncertainty stdev i.setting R hl_first if round>10 & switch~=0 & peru==1
outreg2 using c:\data\sandmo_t1, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xi: mean prod price uncertainty stdev i.setting R hl_first if round>10 & switch~=0 & R>0
outreg2 using c:\data\sandmo_t1, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xi: mean prod price uncertainty stdev i.setting R hl_first if round>10 & switch~=0 & peru==1 & R>0

* Core Results *

outreg2 using c:\data\sandmo_t2a, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod uncertainty R hl_first round cornell minnesota if round>10 & switch~=0, re i(sid) cluster(sid)
more
outreg2 using c:\data\sandmo_t2a, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod uncertainty R round if round>10 & switch~=0 & cornell==1 & december==1, re i(sid) cluster(sid)
more
outreg2 using c:\data\sandmo_t2a, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod uncertainty R round if round>10 & switch~=0 & cornell==1 & march==1, re i(sid) cluster(sid)
more
outreg2 using c:\data\sandmo_t2a, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod uncertainty R round if round>10 & switch~=0 & minnesota==1, re i(sid) cluster(sid)
more
outreg2 using c:\data\sandmo_t2a, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod uncertainty R hl_first round if round>10 & switch~=0 & peru==1, re i(sid) cluster(sid)
more
outreg2 using c:\data\sandmo_t2a, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod uncertainty R hl_first round cornell minnesota if round>10 & switch~=0 & R>0, re i(sid) cluster(sid)
more
outreg2 using c:\data\sandmo_t2a, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod uncertainty R hl_first round if round>10 & switch~=0 & peru==1 & R>0, re i(sid) cluster(sid)
more


outreg2 using c:\data\sandmo_t3a, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod uncertainty stdev R hl_first round cornell minnesota if round>10 & switch~=0, re i(sid) cluster(sid)
more
outreg2 using c:\data\sandmo_t3a, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod uncertainty stdev R round if round>10 & switch~=0 & cornell==1 & december==1, re i(sid) cluster(sid)
more
outreg2 using c:\data\sandmo_t3a, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod uncertainty stdev R round if round>10 & switch~=0 & cornell==1 & march==1, re i(sid) cluster(sid)
more
outreg2 using c:\data\sandmo_t3a, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod uncertainty stdev R round if round>10 & switch~=0 & minnesota==1, re i(sid) cluster(sid)
more
outreg2 using c:\data\sandmo_t3a, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod uncertainty stdev R hl_first round if round>10 & switch~=0 & peru==1, re i(sid) cluster(sid)
more
outreg2 using c:\data\sandmo_t3a, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod uncertainty stdev R hl_first round cornell minnesota if round>10 & switch~=0 & R>0, re i(sid) cluster(sid)
more
outreg2 using c:\data\sandmo_t3a, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod uncertainty stdev R hl_first round if round>10 & switch~=0 & peru==1 & R>0, re i(sid) cluster(sid)
more


outreg2 using c:\data\sandmo_t4a, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod i.setting R hl_first round cornell minnesota if round>10 & switch~=0, re i(sid) cluster(sid)
more
outreg2 using c:\data\sandmo_t4a, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod i.setting R round if round>10 & switch~=0 & cornell==1 & december==1, re i(sid) cluster(sid)
more
outreg2 using c:\data\sandmo_t4a, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod i.setting R round if round>10 & switch~=0 & cornell==1 & march==1, re i(sid) cluster(sid)
more
outreg2 using c:\data\sandmo_t4a, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod i.setting R round if round>10 & switch~=0 & minnesota==1, re i(sid) cluster(sid)
more
outreg2 using c:\data\sandmo_t4a, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod i.setting R hl_first round if round>10 & switch~=0 & peru==1, re i(sid) cluster(sid)
more
outreg2 using c:\data\sandmo_t4a, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod i.setting R hl_first round cornell minnesota if round>10 & switch~=0 & R>0, re i(sid) cluster(sid)
more
outreg2 using c:\data\sandmo_t4a, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod i.setting R hl_first round if round>10 & switch~=0 & peru==1 & R>0, re i(sid) cluster(sid)
more





* Results without Control Variables *

outreg2 using c:\data\sandmo_t2b, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod uncertainty hl_first if round>10 & switch~=0, re i(sid) cluster(sid)
more
outreg2 using c:\data\sandmo_t2b, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod uncertainty if round>10 & switch~=0 & cornell==1 & december==1, re i(sid) cluster(sid)
more
outreg2 using c:\data\sandmo_t2b, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod uncertainty if round>10 & switch~=0 & cornell==1 & march==1, re i(sid) cluster(sid)
more
outreg2 using c:\data\sandmo_t2b, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod uncertainty if round>10 & switch~=0 & minnesota==1, re i(sid) cluster(sid)
more
outreg2 using c:\data\sandmo_t2b, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod uncertainty hl_first if round>10 & switch~=0 & peru==1, re i(sid) cluster(sid)
more
outreg2 using c:\data\sandmo_t2b, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod uncertainty hl_first if round>10 & switch~=0 & R>0, re i(sid) cluster(sid)
more
outreg2 using c:\data\sandmo_t2b, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod uncertainty hl_first if round>10 & switch~=0 & peru==1 & R>0, re i(sid) cluster(sid)
more


outreg2 using c:\data\sandmo_t3b, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod uncertainty stdev hl_first if round>10 & switch~=0, re i(sid) cluster(sid)
more
outreg2 using c:\data\sandmo_t3b, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod uncertainty stdev if round>10 & switch~=0 & cornell==1 & december==1, re i(sid) cluster(sid)
more
outreg2 using c:\data\sandmo_t3b, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod uncertainty stdev if round>10 & switch~=0 & cornell==1 & march==1, re i(sid) cluster(sid)
more
outreg2 using c:\data\sandmo_t3b, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod uncertainty stdev if round>10 & switch~=0 & minnesota==1, re i(sid) cluster(sid)
more
outreg2 using c:\data\sandmo_t3b, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod uncertainty stdev hl_first if round>10 & switch~=0 & peru==1, re i(sid) cluster(sid)
more
outreg2 using c:\data\sandmo_t3b, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod uncertainty stdev hl_first if round>10 & switch~=0 & R>0, re i(sid) cluster(sid)
more
outreg2 using c:\data\sandmo_t3b, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod uncertainty stdev hl_first if round>10 & switch~=0 & peru==1 & R>0, re i(sid) cluster(sid)
more


outreg2 using c:\data\sandmo_t4b, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod i.setting hl_first if round>10 & switch~=0, re i(sid) cluster(sid)
more
outreg2 using c:\data\sandmo_t4b, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod i.setting if round>10 & switch~=0 & cornell==1 & december==1, re i(sid) cluster(sid)
more
outreg2 using c:\data\sandmo_t4b, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod i.setting if round>10 & switch~=0 & cornell==1 & march==1, re i(sid) cluster(sid)
more
outreg2 using c:\data\sandmo_t4b, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod i.setting if round>10 & switch~=0 & minnesota==1, re i(sid) cluster(sid)
more
outreg2 using c:\data\sandmo_t4b, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod i.setting hl_first if round>10 & switch~=0 & peru==1, re i(sid) cluster(sid)
more
outreg2 using c:\data\sandmo_t4b, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod i.setting hl_first if round>10 & switch~=0 & R>0, re i(sid) cluster(sid)
more
outreg2 using c:\data\sandmo_t4b, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod i.setting hl_first if round>10 & switch~=0 & peru==1 & R>0, re i(sid) cluster(sid)
more


* PITA R2's Request that We Do Table 3 Only For Price Risk Observations *

outreg2 using c:\data\sandmo_t3c, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod stdev R hl_first round cornell minnesota if round>10 & switch~=0 & uncertainty==1, re i(sid) cluster(sid)
more
outreg2 using c:\data\sandmo_t3c, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod stdev R round if round>10 & switch~=0 & cornell==1 & december==1 & uncertainty==1, re i(sid) cluster(sid)
more
outreg2 using c:\data\sandmo_t3c, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod stdev R round if round>10 & switch~=0 & cornell==1 & march==1 & uncertainty==1, re i(sid) cluster(sid)
more
outreg2 using c:\data\sandmo_t3c, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod stdev R round if round>10 & switch~=0 & minnesota==1 & uncertainty==1, re i(sid) cluster(sid)
more
outreg2 using c:\data\sandmo_t3c, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod stdev R hl_first round if round>10 & switch~=0 & peru==1 & uncertainty==1, re i(sid) cluster(sid)
more
outreg2 using c:\data\sandmo_t3c, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod stdev R hl_first round cornell minnesota if round>10 & switch~=0 & R>0 & uncertainty==1, re i(sid) cluster(sid)
more
outreg2 using c:\data\sandmo_t3c, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod stdev R hl_first round if round>10 & switch~=0 & peru==1 & R>0 & uncertainty==1, re i(sid) cluster(sid)
more

outreg2 using c:\data\sandmo_t3d, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod stdev hl_first if round>10 & switch~=0 & uncertainty==1, re i(sid) cluster(sid)
more
outreg2 using c:\data\sandmo_t3d, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod stdev if round>10 & switch~=0 & cornell==1 & december==1 & uncertainty==1, re i(sid) cluster(sid)
more
outreg2 using c:\data\sandmo_t3d, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod stdev if round>10 & switch~=0 & cornell==1 & march==1 & uncertainty==1, re i(sid) cluster(sid)
more
outreg2 using c:\data\sandmo_t3d, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod stdev if round>10 & switch~=0 & minnesota==1 & uncertainty==1, re i(sid) cluster(sid)
more
outreg2 using c:\data\sandmo_t3d, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod stdev hl_first if round>10 & switch~=0 & peru==1 & uncertainty==1, re i(sid) cluster(sid)
more
outreg2 using c:\data\sandmo_t3d, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod stdev hl_first if round>10 & switch~=0 & R>0 & uncertainty==1, re i(sid) cluster(sid)
more
outreg2 using c:\data\sandmo_t3d, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod stdev hl_first if round>10 & switch~=0 & peru==1 & R>0 & uncertainty==1, re i(sid) cluster(sid)
more




* Exploring Prospect Theory *

gen pr_5 = 0 if setting==1
gen pr_6 = 0 if setting==1
gen pr_7 = 1 if setting==1
gen pr_8 = 0 if setting==1
gen pr_9 = 0 if setting==1

replace pr_5 = 0 if setting==2
replace pr_6 = 6/20 if setting==2
replace pr_7 = 8/20 if setting==2
replace pr_8 = 6/20 if setting==2
replace pr_9 = 0 if setting==2

replace pr_5 = 2/20 if setting==3
replace pr_6 = 5/20 if setting==3
replace pr_7 = 6/20 if setting==3
replace pr_8 = 5/20 if setting==3
replace pr_9 = 2/20 if setting==3

replace pr_5 = 4/20 if setting==4
replace pr_6 = 4/20 if setting==4
replace pr_7 = 4/20 if setting==4
replace pr_8 = 4/20 if setting==4
replace pr_9 = 4/20 if setting==4

replace pr_5 = 6/20 if setting==5
replace pr_6 = 0 if setting==5
replace pr_7 = 8/20 if setting==5
replace pr_8 = 0 if setting==5
replace pr_9 = 6/20 if setting==5

gen expected_revenue = -15 if prod==0
replace expected_revenue = pr_5*-12 + pr_6*-11 + pr_7*-10 + pr_8*-9 + pr_9*-8 if prod==1
replace expected_revenue = pr_5*-10.28 + pr_6*-8.28 + pr_7*-6.28 + pr_8*-4.28 + pr_9*-2.28 if prod==2
replace expected_revenue = pr_5*-9.31 + pr_6*-6.31 + pr_7*-3.31 + pr_8*-0.31 + pr_9*2.69 if prod==3
replace expected_revenue = pr_5*-8.93 + pr_6*-4.93 + pr_7*-0.93 +pr_8*3.07 + pr_9*7.07 if prod==4
replace expected_revenue = pr_5*-9.04 + pr_6*-4.04 + pr_7*0.96 +pr_8*5.96 + pr_9*10.96 if prod==5
replace expected_revenue = pr_5*-9.57 + pr_6*-3.57 + pr_7*2.43 +pr_8*8.43 + pr_9*14.43 if prod==6
replace expected_revenue = pr_5*-10.49 + pr_6*-3.49 + pr_7*3.51 +pr_8*10.51 + pr_9*17.51 if prod==7
replace expected_revenue = pr_5*-11.76 + pr_6*-3.76 + pr_7*4.24 +pr_8*12.24 + pr_9*20.24 if prod==8
replace expected_revenue = pr_5*-13.35 + pr_6*-4.35 + pr_7*4.65 +pr_8*13.65 + pr_9*22.65 if prod==9
replace expected_revenue = pr_5*-15.24 + pr_6*-5.24 + pr_7*4.76 +pr_8*14.76 + pr_9*24.76 if prod==10
replace expected_revenue = pr_5*-17.41 + pr_6*-6.41 + pr_7*4.59 +pr_8*15.59 + pr_9*26.59 if prod==11
replace expected_revenue = pr_5*-19.85 + pr_6*-7.85 + pr_7*4.15 +pr_8*16.15 + pr_9*28.15 if prod==12
replace expected_revenue = pr_5*-22.54 + pr_6*-9.54 + pr_7*3.46 +pr_8*16.46 + pr_9*29.46 if prod==13
replace expected_revenue = pr_5*-25.47 + pr_6*-11.47 + pr_7*2.53 +pr_8*16.53 + pr_9*30.53 if prod==14
replace expected_revenue = pr_5*-28.63 + pr_6*-13.63 + pr_7*1.37 +pr_8*16.37 + pr_9*31.37 if prod==15
replace expected_revenue = pr_5*-32.01 + pr_6*-16.01 + pr_7*-0.01 +pr_8*15.99 + pr_9*31.99 if prod==16
replace expected_revenue = pr_5*-35.60 + pr_6*-18.60 + pr_7*-1.60 +pr_8*15.40 + pr_9*32.40 if prod==17
replace expected_revenue = pr_5*-39.40 + pr_6*-21.40 + pr_7*-3.40 +pr_8*14.60 + pr_9*32.60 if prod==18
replace expected_revenue = pr_5*-43.39 + pr_6*-24.39 + pr_7*-5.39 +pr_8*13.61 + pr_9*32.61 if prod==19
replace expected_revenue = pr_5*-47.58 + pr_6*-27.58 + pr_7*-7.58 +pr_8*12.42 + pr_9*32.42 if prod==20

gen expected_gain = expected_revenue if expected_revenue>0
replace expected_gain = 0 if expected_revenue<=0

gen expected_loss = abs(expected_revenue) if expected_revenue<0
replace expected_loss = 0 if expected_revenue>0

foreach i of varlist cornell minnesota peru {
gen `i'_exp_gain = `i'*expected_gain
gen `i'_exp_loss = `i'*expected_loss

}

gen pr_5or9 = pr_5
gen pr_6or8 = pr_6

gen pr_small = pr_5or9
gen pr_other = pr_7 + pr_6or8

* Core *

outreg2 using c:\data\sandmo_t8, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod pr_small pr_other expected_gain expected_loss hl_first round cornell minnesota if round>10 & switch~=0, fe i(sid) cluster(sid)
xtreg prod pr_small pr_other expected_gain expected_loss hl_first round cornell minnesota if round>10 & switch~=0, fe i(sid) cluster(sid)
test _b[pr_small] = _b[pr_other]
test _b[expected_gain] = -1*_b[expected_loss]
more


* Cornell *

outreg2 using c:\data\sandmo_t8, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod pr_small pr_other expected_gain expected_loss round if round>10 & switch~=0 & cornell==1 & december==1, fe i(sid) cluster(sid)
xtreg prod pr_small pr_other expected_gain expected_loss round if round>10 & switch~=0 & cornell==1 & december==1, fe i(sid) cluster(sid)
test _b[pr_small] = _b[pr_other]
test _b[expected_gain] = -1*_b[expected_loss]
more

outreg2 using c:\data\sandmo_t8, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod pr_small pr_other expected_gain expected_loss round if round>10 & switch~=0 & cornell==1 & march==1, fe i(sid) cluster(sid)
xtreg prod pr_small pr_other expected_gain expected_loss round if round>10 & switch~=0 & cornell==1 & march==1, fe i(sid) cluster(sid)
test _b[pr_small] = _b[pr_other]
test _b[expected_gain] = -1*_b[expected_loss]
more


* Minnesota *

outreg2 using c:\data\sandmo_t8, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod pr_small pr_other expected_gain expected_loss round if round>10 & switch~=0 & minnesota==1, fe i(sid) cluster(sid)
xtreg prod pr_small pr_other expected_gain expected_loss round if round>10 & switch~=0 & minnesota==1, fe i(sid) cluster(sid)
test _b[pr_small] = _b[pr_other]
test _b[expected_gain] = -1*_b[expected_loss]
more


* Peru

outreg2 using c:\data\sandmo_t8, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod pr_small pr_other expected_gain expected_loss hl_first round if round>10 & switch~=0 & peru==1, fe i(sid) cluster(sid)
xtreg prod pr_small pr_other expected_gain expected_loss hl_first round if round>10 & switch~=0 & peru==1, fe i(sid) cluster(sid)
test _b[pr_small] = _b[pr_other]
test _b[expected_gain] = -1*_b[expected_loss]
more


* Appendix: Switch Points and Rounds as Dummies *

outreg2 using c:\data\sandmo_tA1, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod uncertainty hl_first cornell minnesota i.switch i.round if round>10 & switch~=0, re i(sid) cluster(sid)
more
outreg2 using c:\data\sandmo_tA1, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod uncertainty stdev hl_first cornell minnesota i.switch i.round if round>10 & switch~=0, re i(sid) cluster(sid)
more
outreg2 using c:\data\sandmo_tA1, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xtreg prod i.setting hl_first cornell minnesota i.switch i.round if round>10 & switch~=0, re i(sid) cluster(sid)
more

* Appendix: Switch Point Histograms *

histogram switch if switch~=0 & cornell==1 & december==1, title(Distribution of Holt-Laury Switch Points - Cornell 1)
more

histogram switch if switch~=0 & cornell==1 & march==1, title(Distribution of Holt-Laury Switch Points - Cornell 2)
more

histogram switch if switch~=0 & minnesota==1, title(Distribution of Holt-Laury Switch Points - Minnesota)
more

histogram switch if switch~=0 & peru==1, title(Distribution of Holt-Laury Switch Points - Peru)
more



